<?php
	
	class MBLWPPublic
	{
		
		public function __construct()
		{
			$this->_setHooks();
		}
		
		private function _setHooks()
		{
			if (!is_admin()) {
				$this->_addStyles();
				$this->_addScripts();
			}
			
			add_filter('video_html', array($this, 'checkUcBrowser'));
		}
		
		private function _addStyles()
		{
			add_action("wpm_head", array($this, 'addStyles'));
		}
		
		public function addStyles()
		{
			wpm_enqueue_style('mbl_wp_style', plugins_url('/mbl-protection/assets/css/main.css?v=' . MBL_WP_VERSION));
		}
		
		private function _addScripts()
		{
			add_action("wpm_footer", array($this, 'addScripts'));
		}
		
		public function addScripts()
		{
			if (is_user_logged_in()) {
				wpm_enqueue_script('mbl_wp_script', plugins_url('/mbl-protection/assets/js/main.js?v=' . MBL_WP_VERSION));
				
				$user = wp_get_current_user();
				$options = wpm_get_option('mbl_wp');
				
				$options['block_0']['text'] = self::the_protection_text_for_block(0, $user);
				$options['block_1']['text'] = self::the_protection_text_for_block(1, $user);
				$options['block_2']['text'] = self::the_protection_text_for_block(2, $user);
				$options['block_3']['text'] = self::the_protection_text_for_block(3, $user);
				$options['block_4']['text'] = self::the_protection_text_for_block(4, $user);
				
				$options = json_encode($options);
				
				?>
                <script>
                    var mbl_wp = JSON.parse(JSON.stringify( <?php echo $options ?> ));
                </script>
                
				<?php
			}
		}
		
		public function the_protection_text_for_block($block, $user)
		{
			
			$block_status = wpm_get_option('mbl_wp.block_' . $block . '.display');
			$data_type = wpm_get_option('mbl_wp.block_' . $block . '.data_type');
			$text = '';
			
			if ($block_status == 'on') {
			    
			    if(!$data_type)
			        $text = wpm_get_option('mbl_wp.block_' . $block . '.text');
				elseif ($data_type == 'fio') {
					$text = get_user_meta( $user->id, 'last_name', true ).' '.get_user_meta( $user->id, 'first_name', true ).' '.get_user_meta( $user->id, 'surname', true );
				}elseif ($data_type == 'mail')
					$text = $user->user_email;
                elseif ($data_type == 'pin') {
	
					global $post;
					global $wpdb;
					$table = MBLTermKeysQuery::getTable();
	
					$terms = wp_get_post_terms( $post->ID, 'wpm-levels', ['fields'=>'ids'] );
					$terms = implode(',', $terms);
	
					$key = $wpdb->get_results("
			        SELECT *
			        FROM $table
			        WHERE user_id = $user->id AND status = 'used' AND term_id IN ($terms)
			        ORDER BY date_registered DESC LIMIT 0,1
			        ");
					
					$text = $key[0]->key ? $key[0]->key : '';
                }
					
                elseif ($data_type == 'login')
					$text = wp_get_current_user()->user_login;
			}
			
			return $text;
		}
		
		public function checkUcBrowser($html)
		{
		    if( preg_match('/UCBrowser/', $_SERVER['HTTP_USER_AGENT']) ) {
				$html = '<div class="plur_not_supported">' . wpm_get_option('mbl_wp.uc_text') . '</div>';
            }
		    
			return $html;
		}
	}